import osc_sdk_python
from diagrams import Cluster, Diagram
from diagrams.outscale.compute import Compute
from diagrams.outscale.security import IdentityAndAccessManagement
from diagrams.outscale.storage import Storage 
import os

key = ""
secret = ""

try:
    key = os.environ['OSC_ACCESS_KEY']
    secret = os.environ["OSC_SECRET_KEY"]
except:
    pass

region = "eu-west-2"
service = "api"

def sn(str):
    if len(str) > 16:
        return str[:14] + "..."
    return str

def main(ak=key, sk=secret, format=["png", "dot"], region=region, service=service):
    driver = osc_sdk_python.Gateway(access_key=ak, secret_key=sk, region=region)

    nodes = driver.ReadVms()["Vms"]

    with Diagram("All Vms", outformat=format, direction="BT"):
        for n in nodes:
            nname = n["Tags"][0]["Value"] if len(n["Tags"]) else "(no Name)"
            ip = n['PublicIp'] if 'PublicIp' in n else ""
            vm = Compute(sn(nname) + '\n`' + ip)
            with Cluster("SG:\n" + nname + '\n' + n['VmId']):
                sgs_cluster = []
                if 'SecurityGroups' in n:
                    for sg in n['SecurityGroups']:
                        sg_name = sg["SecurityGroupName"]
                        sgs_cluster.append(IdentityAndAccessManagement(sn(sg_name)))
                    
            with Cluster("Devs:\n" + nname + '\n' + n['VmId']):
                bd_cluster = []
                if 'BlockDeviceMappings' in n:
                    for bd in  n['BlockDeviceMappings']:
                        dev_name = bd["DeviceName"]
                        bd_cluster.append(Storage(sn(dev_name) + "\n" + bd["Bsu"]["VolumeId"]))
            vm >> sgs_cluster
            vm >> bd_cluster


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
import setuptools
import os

def get_long_description():
    root_path = os.path.dirname(os.path.abspath(__file__))
    with open(os.path.join(root_path, 'README.md'), 'r') as fd:
        return fd.read()

def get_version():
    root_path = os.path.dirname(os.path.abspath(__file__))
    with open(os.path.join(root_path, 'osc_diagram', 'VERSION'), 'r') as fd:
        return fd.read().strip()

setuptools.setup(
    name='osc-diagram',
    version=get_version(),
    author="Outscal SAS",
    author_email="opensource@outscale.com",
    description="Outscale Gateway python SDK",
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    include_package_data=True,
    url="https://github.com/outscale-mgo/osc-diagram",
    packages=setuptools.find_packages(),
    entry_points={"console_scripts": ["osc-diagram = osc_diagram.main:main"]},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "osc-sdk-python>=0.22.0",
        'diagrams>=0.23.3'
    ]
)
